<?php
namespace Teknisa\MAN\Controllers;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\MAN\Services\RelDREService;
use Teknisa\MAN\Services\RelDREComparativoService;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;
use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\Report\ReportService;

class RelVendasConsumidorPeriodo  extends  CrudWithParameterBag { 
    
     protected $utilService,
               $parameterBagColumns = array('NRORG');
     protected $formatBirt;
     
     public function __construct ($crudService, $parameterBag, $entityManager, Utilities\Util $utilService, Manager $dataSourceManager,
                                  BirtReport $birtReport, ReportService $reportService, $relatorioService) {
        $this->crudService          = $crudService;
        $this->parameterBag         = $parameterBag;
        $this->entityManager        = $entityManager;
        $this->utilService          = $utilService;
        $this->dataSourceManager    = $dataSourceManager;
        $this->birtReport           = $birtReport;
        $this->reportService        = $reportService;
        $this->relatorioService     = $relatorioService;
    }
    
    public function findRelatorio(DTO\Request\Row $request, DTO\Response $response) {
        $conditions = $this->utilService->getParamsAsArray($request);
        $this->relatorioService->setTCDandCDChangingKey($conditions, 'CDFILIAL', 'CDFILIAL');
        $this->relatorioService->setTCDandCDChangingKey($conditions, 'CDFILICAIXA', 'CDFILICAIXA');
        $this->relatorioService->setTCDandCDChangingKey($conditions, 'CDVENDEDOR', 'CDVENDEDOR');
        $this->relatorioService->setTCDandCDChangingKey($conditions, 'CDCONSUMIDOR', 'CDCONSUMIDOR');
        $this->relatorioService->setTCDandCDChangingKey($conditions, 'CDTIPOCONS', 'CDTIPOCONS');
        $this->relatorioService->setTCDandCDChangingKey($conditions, 'CDCLIENTE', 'CDCLIENTE');
        $this->relatorioService->setTCDandCDChangingKey($conditions, 'CDTIPORECE', 'CDTIPORECE');
        $this->relatorioService->setCustomDate($conditions, 'DTPERIODO', 'DATAINI', 'DATAFIN');
        $params = $this->conditionsParamBuild($conditions);
        
        $this->getReport($params, $response);
    }
    
    public function conditionsParamBuild($conditions){
       $params = array (      
            ':NRORG'        => $conditions['NRORG'], 
            ':CDFILIAL'       => (!$conditions['CDFILIAL']) ? "T" : $conditions['CDFILIAL'],
            ':CDFILICAIXA'        => (!$conditions['CDFILICAIXA']) ? "T" : $conditions['CDFILICAIXA'],
            ':CDVENDEDOR'       => (!$conditions['CDVENDEDOR']) ? "T" : $conditions['CDVENDEDOR'],
            ':CDCONSUMIDOR'       => (!$conditions['CDCONSUMIDOR']) ? "T" : $conditions['CDCONSUMIDOR'],
            ':CDTIPOCONS'       => (!$conditions['CDTIPOCONS']) ? "T" : $conditions['CDTIPOCONS'],
            ':CDCLIENTE'       => (!$conditions['CDCLIENTE']) ? "T" : $conditions['CDCLIENTE'],
            ':DATAINI'        => $conditions['DATAINI'],
            ':DATAFIN'        => $conditions['DATAFIN']
        );
        
        $params = array(
            'ParametersRow' => $params,
            'ReportName'    => 'RelVendasConsumidorPeriodo'
        );
        
        return $params;
    }
    
    public function getReport($params, DTO\Response $response){
        try {
            $birtURL = $this->reportService->createRemoteReport('BIRT', $params['ReportName'], $params['ParametersRow']);
            $response->addDataset(new DataSet('URL',array('url'=>$birtURL)));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage() , 500));
        }
    }
    
    
    
}
